[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Kosmos
My implementation of the model KosmosG from "KOSMOS-G: Generating Images in Context with Multimodal Large Language Models"



## Installation

You can install the package using pip


# License
MIT



